package com.docus.server.api.segmentation;

import com.docus.infrastructure.web.request.SearchDTO;
import com.docus.infrastructure.web.response.PageResult;
import com.docus.server.dto.segmentation.ocrurlconfig.AddOcrUrlConfigDTO;
import com.docus.server.dto.segmentation.ocrurlconfig.DeleteOcrUrlConfigDTO;
import com.docus.server.dto.segmentation.ocrurlconfig.EditOcrUrlConfigDTO;
import com.docus.server.vo.segmentation.ocrurlconfig.OcrUrlConfigVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.List;


/**
 * ocr路径配置表 API
 *
 * @author AutoGenerator
 * @since 2023-08-29
 */
@FeignClient(value = "docus-segmentation", contextId = "docus-segmentation.OcrUrlConfigApi")
@RequestMapping("/ocr/UrlConfig")
public interface OcrUrlConfigApi {

    /**
     * 按主键查询
     *
     * @param id 主键id
     * @return 实体
     */
    @GetMapping("/find/{id}")
    OcrUrlConfigVO findById(@PathVariable(value = "id") Long id);

    /**
     * 查询所有
     *
     * @return 实体
     */
    @GetMapping("/findAll")
    List<OcrUrlConfigVO> findAll();

    /**
     * 关键字搜索
     *
     * @param searchDTO 搜索参数
     * @return 分页列表
     */
    @PostMapping("/search")
    PageResult<OcrUrlConfigVO> search(@RequestBody SearchDTO searchDTO);

    /**
     * 新增
     *
     * @param addOcrUrlConfigDTO 新增参数
     */
    @PostMapping("/add")
    void add(@RequestBody AddOcrUrlConfigDTO addOcrUrlConfigDTO);

    /**
     * 编辑
     *
     * @param editOcrUrlConfigDTO 编辑参数
     */
    @PutMapping("/edit")
    void edit(@RequestBody EditOcrUrlConfigDTO editOcrUrlConfigDTO);

    /**
     * 批量删除
     *
     * @param deleteOcrUrlConfigDTO 删除参数
     * @return 成功或失败
     */
    @DeleteMapping("/delete")
    int delete(@RequestBody DeleteOcrUrlConfigDTO deleteOcrUrlConfigDTO);
}
