package com.docus.server.controller;

import com.docus.server.common.event.FlowEvent;
import com.docus.server.common.service.IFileUploadService;
import com.docus.server.dto.segmentation.UploadBatchFileRequest;
import com.docus.server.service.IPublishEventService;
import com.docus.server.service.impl.CommonService;
import com.docus.server.service.impl.PlatformServiceImpl;
import com.docus.server.vo.scheduling.management.schcollectorversionfile.UploadFileVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文件上传下载 API
 *
 * @author AutoGenerator
 * @since 2023-07-15
 */
@Api(value = "通用文件上传下载接口", tags = "通用文件上传下载接口")
@RestController
@RequestMapping("/ocr/file")
public class FileController {
    @Resource
    private IFileUploadService iFileUploadService;
    @Resource
    private PlatformServiceImpl downloadService;
    @Resource
    private CommonService commonService;
    @Resource
    private IPublishEventService iPublishEventService;

    @ApiOperation("文件下载")
    @GetMapping("/download")
    public void downloadFile(String filePath, HttpServletResponse response) throws Exception {
        iFileUploadService.downloadFile(filePath, response);
    }

    @ApiOperation("文件上传")
    @PostMapping("/upload")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "files", value = "文件", required = true, dataTypeClass = MultipartFile.class)
    })
    public void uploadFile(@RequestPart("files") MultipartFile[] files, @Validated UploadBatchFileRequest request) throws Exception {
        List<UploadFileVO> segmentation = iFileUploadService.uploadFile(files, "segmentation");

        //将基础信息存到库表里面，后面自动分段后，需要上传到归档系统
        commonService.add(segmentation, request);

        iPublishEventService.publishEvent(request.getPatientId(), FlowEvent.FlowTypeEnum.START_SEGMENT);
    }

    /**
     * 下载平台
     *
     * @throws Exception
     */
    @ApiOperation("批量上传文件到归档系统")
    @GetMapping("/uploadPlatform")
    public void uploadPlatform() throws Exception {
        downloadService.uploadPlatform(null, null);
    }
}
