package com.docus.server.service.impl;

import com.docus.infrastructure.redis.service.IdService;
import com.docus.infrastructure.web.request.SearchDTO;
import com.docus.infrastructure.web.response.PageResult;
import com.docus.server.convert.OcrCutConfigConvert;
import com.docus.server.dto.segmentation.ocrcutconfig.AddOcrCutConfigDTO;
import com.docus.server.dto.segmentation.ocrcutconfig.DeleteOcrCutConfigDTO;
import com.docus.server.dto.segmentation.ocrcutconfig.EditOcrCutConfigDTO;
import com.docus.server.entity.segmentation.OcrCutConfig;
import com.docus.server.infrastructure.dao.IOcrCutConfigDao;
import com.docus.server.service.IOcrCutConfigService;
import com.docus.server.vo.segmentation.ocrcutconfig.OcrCutConfigVO;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * ocr图片剪切配置 服务实现类
 *
 * @author AutoGenerator
 * @since 2023-08-29
 */
@Service
public class OcrCutConfigServiceImpl implements IOcrCutConfigService {
    @Resource
    private IOcrCutConfigDao iOcrCutConfigDao;
    @Resource
    private IdService idService;

    /**
     * 按主键查询
     *
     * @param id 主键Id
     * @return 实体
     */
    @Override
    public OcrCutConfigVO findById(Long id) {
        return OcrCutConfigConvert.INSTANCE.convertVO(iOcrCutConfigDao.findById(id));
    }

    /**
     * 查询所有
     *
     * @return 实体
     */
    @Override
    public List<OcrCutConfigVO> findAll() {
        return OcrCutConfigConvert.INSTANCE.convertVO(iOcrCutConfigDao.findAll());
    }

    /**
     * 关键字搜索
     *
     * @param searchDTO 搜索参数
     * @return 分页列表
     */
    @Override
    public PageResult<OcrCutConfigVO> search(SearchDTO searchDTO) {
        return OcrCutConfigConvert.INSTANCE.convertVO(iOcrCutConfigDao.search(searchDTO));

        //PageResult<OcrCutConfigVO> result = OcrCutConfigConvert.INSTANCE.convertVO(iOcrCutConfigDao.search(searchDTO));

        //if (CollectionUtils.isEmpty(result.getList())) {
        //return new PageResult<>();
        //}

        //Map<String, SchSystemParams> map = iSchSystemParamsService.find(ListUtils.distinctSelect(result.getList(), SchCollectorVO::getCollectorId));

        //result.getList().forEach(p -> {
        // String collectorId = String.valueOf(p.getCollectorId());
        // if (map.containsKey(collectorId)) {
        //     p.setCollectorName(map.get(collectorId).getParamName());
        // }
        //});

        //return result;
    }

    /**
     * 新增
     *
     * @param addOcrCutConfigDTO 编辑参数
     * @return 成功或失败
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean add(AddOcrCutConfigDTO addOcrCutConfigDTO) {
        OcrCutConfig ocrCutConfig = OcrCutConfigConvert.INSTANCE.convertDO(addOcrCutConfigDTO);
        ocrCutConfig.setId(idService.getDateSeq());
        return iOcrCutConfigDao.add(ocrCutConfig);

        // String name = addOcrCutConfigDTO.getName();

        //OcrCutConfig ocrCutConfig = iOcrCutConfigDao.findOneBy("name", name);

        //if (Func.notNull(ocrCutConfig)) {
        // throw new ApiException(ExceptionCode.ParamIllegal.getCode(), "ocr图片剪切配置已经存在");
        // }

        // OcrCutConfig ocrCutConfig =OcrCutConfigConvert.INSTANCE.convertDO(addOcrCutConfigDTO);
        // ocrCutConfig.setId(idService.getDateSeq());

        // return iOcrCutConfigDao.add(schCollector);

    }

    /**
     * 编辑
     *
     * @param editOcrCutConfigDTO 编辑参数
     * @return 成功或失败
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean edit(EditOcrCutConfigDTO editOcrCutConfigDTO) {
        OcrCutConfig ocrCutConfig = OcrCutConfigConvert.INSTANCE.convertDO(editOcrCutConfigDTO);
        return iOcrCutConfigDao.edit(ocrCutConfig);

        // Long id = editOcrCutConfigDTO.getId();

        //  OcrCutConfig ocrCutConfig = iOcrCutConfigDao.findById(id);

        // if (Func.isNull(ocrCutConfig)) {
        //     throw new ApiException(ExceptionCode.ParamIllegal.getCode(), "ocr图片剪切配置，无法更新！");
        // }

        // ocrCutConfig.setUpdateTime(LocalDateTime.now());
        // return iOcrCutConfigDao.edit(ocrCutConfig);
    }

    /**
     * 批量删除
     *
     * @param deleteOcrCutConfigDTO 删除参数
     * @return 成功或失败
     */
    @Override
    public int delete(DeleteOcrCutConfigDTO deleteOcrCutConfigDTO) {
        return iOcrCutConfigDao.delete(deleteOcrCutConfigDTO.getIds());
    }
}

