package com.docus.server.service.impl;

import com.docus.infrastructure.redis.service.IdService;
import com.docus.infrastructure.web.request.SearchDTO;
import com.docus.infrastructure.web.response.PageResult;
import com.docus.server.convert.OcrVersionConvert;
import com.docus.server.dto.segmentation.ocrversion.AddOcrVersionDTO;
import com.docus.server.dto.segmentation.ocrversion.DeleteOcrVersionDTO;
import com.docus.server.dto.segmentation.ocrversion.EditOcrVersionDTO;
import com.docus.server.entity.segmentation.OcrVersion;
import com.docus.server.infrastructure.dao.IOcrVersionDao;
import com.docus.server.service.IOcrVersionService;
import com.docus.server.vo.segmentation.ocrversion.OcrVersionVO;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 正式数据版本号管理 服务实现类
 *
 * @author AutoGenerator
 * @since 2023-08-29
 */
@Service
public class OcrVersionServiceImpl implements IOcrVersionService {
    @Resource
    private IOcrVersionDao iOcrVersionDao;
    @Resource
    private IdService idService;

    /**
     * 按主键查询
     *
     * @param id 主键Id
     * @return 实体
     */
    @Override
    public OcrVersionVO findById(Long id) {
        return OcrVersionConvert.INSTANCE.convertVO(iOcrVersionDao.findById(id));
    }

    /**
     * 查询所有
     *
     * @return 实体
     */
    @Override
    public List<OcrVersionVO> findAll() {
        return OcrVersionConvert.INSTANCE.convertVO(iOcrVersionDao.findAll());
    }

    /**
     * 关键字搜索
     *
     * @param searchDTO 搜索参数
     * @return 分页列表
     */
    @Override
    public PageResult<OcrVersionVO> search(SearchDTO searchDTO) {
        return OcrVersionConvert.INSTANCE.convertVO(iOcrVersionDao.search(searchDTO));

        //PageResult<OcrVersionVO> result = OcrVersionConvert.INSTANCE.convertVO(iOcrVersionDao.search(searchDTO));

        //if (CollectionUtils.isEmpty(result.getList())) {
        //return new PageResult<>();
        //}

        //Map<String, SchSystemParams> map = iSchSystemParamsService.find(ListUtils.distinctSelect(result.getList(), SchCollectorVO::getCollectorId));

        //result.getList().forEach(p -> {
        // String collectorId = String.valueOf(p.getCollectorId());
        // if (map.containsKey(collectorId)) {
        //     p.setCollectorName(map.get(collectorId).getParamName());
        // }
        //});

        //return result;
    }

    /**
     * 新增
     *
     * @param addOcrVersionDTO 编辑参数
     * @return 成功或失败
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean add(AddOcrVersionDTO addOcrVersionDTO) {
        OcrVersion ocrVersion = OcrVersionConvert.INSTANCE.convertDO(addOcrVersionDTO);
        ocrVersion.setId(idService.getDateSeq());
        return iOcrVersionDao.add(ocrVersion);

        // String name = addOcrVersionDTO.getName();

        //OcrVersion ocrVersion = iOcrVersionDao.findOneBy("name", name);

        //if (Func.notNull(ocrVersion)) {
        // throw new ApiException(ExceptionCode.ParamIllegal.getCode(), "正式数据版本号管理已经存在");
        // }

        // OcrVersion ocrVersion =OcrVersionConvert.INSTANCE.convertDO(addOcrVersionDTO);
        // ocrVersion.setId(idService.getDateSeq());

        // return iOcrVersionDao.add(schCollector);

    }

    /**
     * 编辑
     *
     * @param editOcrVersionDTO 编辑参数
     * @return 成功或失败
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean edit(EditOcrVersionDTO editOcrVersionDTO) {
        OcrVersion ocrVersion = OcrVersionConvert.INSTANCE.convertDO(editOcrVersionDTO);
        return iOcrVersionDao.edit(ocrVersion);

        // Long id = editOcrVersionDTO.getId();

        //  OcrVersion ocrVersion = iOcrVersionDao.findById(id);

        // if (Func.isNull(ocrVersion)) {
        //     throw new ApiException(ExceptionCode.ParamIllegal.getCode(), "正式数据版本号管理，无法更新！");
        // }

        // ocrVersion.setUpdateTime(LocalDateTime.now());
        // return iOcrVersionDao.edit(ocrVersion);
    }

    /**
     * 批量删除
     *
     * @param deleteOcrVersionDTO 删除参数
     * @return 成功或失败
     */
    @Override
    public int delete(DeleteOcrVersionDTO deleteOcrVersionDTO) {
        return iOcrVersionDao.delete(deleteOcrVersionDTO.getIds());
    }
}

